@@ -47,6 +47,7 @@ async def exec():
     args.packages.extend(const.REQUIRED_PACKAGES)
 
     print(f'Creating virtual environment at {venv_path}')
+
     if args.python:
         await run_cmd([
             args.python,
@@ -68,6 +69,10 @@ async def exec():
             str(project_path / '.env'),
             utils.generate_env(args.debug, args.hosts)
         ),
+        write_file(
+            str(project_path / 'README.md'),
+            const.README
+        ),
         write_file(
             str(project_path / 'env.example'),
             const.ENV_EXAMPLE
