@@ -7,6 +7,7 @@ import aiofiles
 
 from .process import run_cmd, Process
 from .files import write_file
+from build_django import const
 
 
 def generate_env(debug: bool = False, hosts: str = '*') -> str:
@@ -30,7 +31,7 @@ async def edit_settings(file) -> list[str]:
 
             result.append(f'\n{line}\n')
 
-            result.append('\nenv = Env(DEBUG=(bool, False))\n')
+            result.append(f'\nenv = Env({const.DEFAULT_ENV})\n')
 
             result.append('\nEnv.read_env(BASE_DIR / \'.env\')\n')
 
@@ -43,6 +44,12 @@ async def edit_settings(file) -> list[str]:
         else:
             result.append(line)
 
+    result.extend((
+        '\n# Custom settings\n'
+        "\nif env('USE_SSL'):\n",
+        ' ' * 4 + "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')"
+    ))
+
     return result
 
 
